@@ -10,7 +10,7 @@ import enum
 import sqlalchemy as sa
 from alembic import op
 
-from . import get_trigger_name, get_function_name
+from .naming import get_trigger_name, get_function_name
 from .extract_columns import extract_columns, get_column_to_dependency_columns
 from .utils import apply_prefix
 
